@@ -237,7 +237,7 @@ void update_fp_entries(string sbin, int base, const Number *decnum) {
 		} else {
 			if(sbin.length() < bits) sbin.insert(0, bits - sbin.length(), '0');
 			Number exponent, significand;
-			exponent.set(sbin.substr(1, expbits), pa);
+			exponent.set(sbin.substr(sgnpos == 0 ? 1 : 0, expbits), pa);
 			Number expbias(2);
 			expbias ^= (expbits - 1);
 			expbias--;
@@ -252,9 +252,9 @@ void update_fp_entries(string sbin, int base, const Number *decnum) {
 				sfloathex = sfloat;
 			} else {
 				if(subnormal) exponent++;
-				if(subnormal) significand.set(string("0.") + sbin.substr(1 + expbits), pa);
-				else significand.set(string("1.") + sbin.substr(1 + expbits), pa);
-				if(sbin[0] != '0') significand.negate();
+				if(subnormal) significand.set(string("0.") + sbin.substr((bits == 80 ? 2 : 1) + expbits), pa);
+				else significand.set(string("1.") + sbin.substr((bits == 80 ? 2 : 1) + expbits), pa);
+				if(sbin[sgnpos] != '0') significand.negate();
 				int exp_bak = po.min_exp;
 				po.min_exp = 0;
 				sfloat = significand.print(po);
@@ -263,7 +263,9 @@ void update_fp_entries(string sbin, int base, const Number *decnum) {
 					sfloat += expression_times_sign();
 					sfloat += " ";
 					sfloat += "2^";
+					po.digit_grouping = DIGIT_GROUPING_NONE;
 					sfloat += exponent.print(po);
+					po.digit_grouping = printops.digit_grouping;
 				}
 				if(b_approx) sfloat.insert(0, SIGN_ALMOST_EQUAL " ");
 				b_approx = false;
