@@ -26,6 +26,7 @@ void restore_window(GtkWindow *win = NULL);
 void create_main_window(void);
 
 GtkWindow *main_window();
+bool on_wayland();
 
 void update_accels(int type = -1);
 void set_app_font(const char *str);
@@ -96,6 +97,8 @@ void set_parsed_in_result(bool b);
 void show_parsed(bool);
 void show_parsed_in_result(MathStructure &mparse, const PrintOptions &po);
 void clear_parsed_in_result();
+void set_expression_pos(int);
+int get_expression_pos();
 
 void set_autocalculate(bool b);
 void add_autocalculated_result_to_history();
@@ -204,5 +207,8 @@ void load_preferences();
 bool save_preferences(bool mode = false, bool allow_cancel = false);
 bool save_history(bool allow_cancel = false);
 
+void start_test();
+void stop_test();
+
 #endif
 
